:mod:`niapy`
============

:mod:`niapy.runner`
-------------------
.. automodule:: niapy.runner
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`niapy.task`
-----------------
.. automodule:: niapy.task
    :members:
    :undoc-members:
    :show-inheritance:
